tnschooldata: Fetch and Process Tennessee School Data
Source:R/tnschooldata-package.R
tnschooldata-package.RdDownloads and processes school data from the Tennessee Department of Education (TDOE). Provides functions for fetching enrollment data from the Education Information System (EIS) and Report Card data, transforming it into tidy format for analysis.
Main functions
fetch_enrFetch enrollment data for a school year
fetch_enr_multiFetch enrollment data for multiple years
tidy_enrTransform wide data to tidy (long) format
id_enr_aggsAdd aggregation level flags
enr_grade_aggsCreate grade-level aggregations
get_available_yearsGet available data years
Cache functions
cache_statusView cached data files
clear_cacheRemove cached data files
ID System
Tennessee uses the following ID system:
District IDs: 4 digits, zero-padded (e.g., 0470 = Knox County)
School IDs: 4 digits within district
Campus IDs: 8 digits (district ID + school ID)
Data Sources
Data is sourced from the Tennessee Department of Education:
Data Downloads: https://www.tn.gov/education/districts/federal-programs-and-oversight/data/data-downloads.html
State Report Card: https://tdepublicschools.ondemand.sas.com/
Annual Statistical Report: https://www.tn.gov/education/districts/federal-programs-and-oversight/data/department-reports.html
Format Eras
Tennessee data is available in two main eras:
Legacy Era (2012-2018): Older Excel format files
Modern Era (2019-2024): Standardized Report Card data system
Tennessee Education Regions
Tennessee is divided into 8 CORE (Centers of Regional Excellence) regions:
Region 1: Upper East Tennessee
Region 2: East Tennessee
Region 3: Southeast Tennessee
Region 4: Upper Cumberland
Region 5: Mid-Cumberland (Nashville area)
Region 6: South Central Tennessee
Region 7: Northwest Tennessee
Region 8: Southwest Tennessee (Memphis area)
Author
Maintainer: Al Martin almartin@example.com